document.addEventListener('DOMContentLoaded', function() {
    // Mock metadata for demonstration
    const mockMetadata = {
        tables: {
            users: ['id', 'name', 'email', 'created_at'],
            orders: ['id', 'user_id', 'total', 'status', 'order_date'],
            products: ['id', 'name', 'price', 'category']
        }
    };

    // Initialize the app
    initializeMetadata(mockMetadata);
    setupEventListeners();
});

function initializeMetadata(metadata) {
    const metadataDisplay = document.getElementById('metadata-display');
    const tableList = document.getElementById('table-list');
    
    // Clear loading message
    metadataDisplay.innerHTML = '<h3>Available Tables</h3>';
    
    // Create table selections
    Object.keys(metadata.tables).forEach(tableName => {
        const tableDiv = document.createElement('div');
        tableDiv.innerHTML = `
            <label>
                <input type="checkbox" name="table" value="${tableName}">
                ${tableName}
            </label>
        `;
        tableList.appendChild(tableDiv);
    });
}

function setupEventListeners() {
    // Table selection handler
    document.getElementById('table-list').addEventListener('change', function(e) {
        if (e.target.type === 'checkbox') {
            updateColumnSelection(e.target);
        }
    });

    // Transform button handlers
    document.querySelectorAll('.transform-btn').forEach(btn => {
        btn.addEventListener('click', function() {
            handleTransformation(this.dataset.type);
        });
    });

    // Copy button handler
    document.getElementById('copy-btn').addEventListener('click', function() {
        const queryText = document.querySelector('#query-result code').textContent;
        navigator.clipboard.writeText(queryText)
            .then(() => alert('Query copied to clipboard!'))
            .catch(err => console.error('Failed to copy:', err));
    });

    // Custom input handler
    let timeout;
    document.getElementById('custom-input').addEventListener('input', function() {
        clearTimeout(timeout);
        timeout = setTimeout(() => generateQuery(), 1000);
    });
}

function updateColumnSelection(tableCheckbox) {
    const columnList = document.getElementById('column-list');
    if (tableCheckbox.checked) {
        // Mock columns for demo
        const columns = ['id', 'name', 'email', 'created_at'];
        columns.forEach(col => {
            const colDiv = document.createElement('div');
            colDiv.innerHTML = `
                <label>
                    <input type="checkbox" name="column" value="${col}" data-table="${tableCheckbox.value}">
                    ${tableCheckbox.value}.${col}
                </label>
            `;
            columnList.appendChild(colDiv);
        });
    } else {
        // Remove columns for unchecked table
        const tableColumns = columnList.querySelectorAll(`[data-table="${tableCheckbox.value}"]`);
        tableColumns.forEach(col => col.parentElement.parentElement.remove());
    }
}

function handleTransformation(type) {
    const configDiv = document.getElementById('transformation-config');
    configDiv.innerHTML = ''; // Clear previous config

    switch(type) {
        case 'sort':
            configDiv.innerHTML = `
                <select id="sort-column">
                    <option>Select column</option>
                </select>
                <select id="sort-direction">
                    <option value="ASC">Ascending</option>
                    <option value="DESC">Descending</option>
                </select>
            `;
            break;
        // Add other transformation types as needed
    }

    generateQuery();
}

function generateQuery() {
    // Collect all selections and transformations
    const selections = {
        tables: Array.from(document.querySelectorAll('input[name="table"]:checked'))
            .map(cb => cb.value),
        columns: Array.from(document.querySelectorAll('input[name="column"]:checked'))
            .map(cb => `${cb.dataset.table}.${cb.value}`),
        customInput: document.getElementById('custom-input').value
    };

    // In a real application, this would call the ChatGPT API
    // For demo, just show a mock query
    const mockQuery = `SELECT ${selections.columns.join(', ')}
FROM ${selections.tables.join(' JOIN ')}
WHERE /* conditions based on custom input: ${selections.customInput} */`;

    document.querySelector('#query-result code').textContent = mockQuery;
}
